@@ -1,18 +1,9 @@
-#!/usr/bin/perl -w
+#!/usr/bin/perl
 ##
 #
 # $Author: alex $
-# $Revision: 1.5 $
+# $Revision: 1.2 $
 # $Log: test.pl,v $
-# Revision 1.5  1999/02/19 16:06:52  alex
-# UnFixed use Tk 800
-#
-# Revision 1.4  1999/02/10 16:59:33  alex
-# *** Empty log message ***
-#
-# Revision 1.3  1999/02/09 22:23:19  alex
-# nothing important
-#
 # Revision 1.2  1999/02/04 11:25:46  alex
 # First stable version
 #
@@ -48,21 +39,19 @@ print "ok 1\n";
 my $wm=MainWindow->new();
 
 my $text=$wm->Scrolled('SuperText','-scrollbars' => 'se','-wrap' => 'none',
-  '-borderwidth' => 0,'-width' => 80,'-height' => 40,'-indentmode' => 'auto',
-  '-background' => 'white','-foreground' => 'blue'
-  );
+  '-borderwidth' => 0,'-width' => 80,'-height' => 40,'-indentmode' => 'auto');
 
 $text->pack('-fill' => 'both','-expand' => 'true');
 $text->focus;
 
-$text->bind('Tk::Text::SuperText','<<pippo>>',\&pippo);
-$text->eventAdd('<<pippo>>','<Control-p>','<Control-Key-1>');
+$text->bind('Tk::Text::SuperText','<<PrintCouples>>',\&print_couples);
+$text->eventAdd('<<PrintCouples>>','<Control-p>','<Control-Key-1>');
 
 MainLoop;
 
 print "ok 2\n";
 
-sub pippo
+sub print_couples
 {
 	my $w = shift;
 	
